@@ -1,19 +1,12 @@
+from __future__ import annotations
+
 import inspect
 from base64 import b32encode
+from collections.abc import MutableMapping
 from copy import copy
-from enum import IntEnum, Enum
+from enum import Enum, IntEnum
 from hashlib import sha3_224
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    List,
-    MutableMapping,
-    Optional,
-    Tuple,
-    Type,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, Optional, Union
 
 from pydantic import ConfigDict
 from pydantic import Field as PydanticField
@@ -34,12 +27,12 @@ from tortoise.contrib.pydantic.descriptions import (
 )
 from tortoise.contrib.pydantic.utils import get_annotations
 from tortoise.fields import Field, JSONField
-from tortoise.fields.data import IntEnumFieldInstance, CharEnumFieldInstance
+from tortoise.fields.data import CharEnumFieldInstance, IntEnumFieldInstance
 
 if TYPE_CHECKING:  # pragma: nocoverage
     from tortoise.models import Model
 
-_MODEL_INDEX: Dict[str, Type[PydanticModel]] = {}
+_MODEL_INDEX: dict[str, type[PydanticModel]] = {}
 """
 The index works as follows:
 1. the hash is calculated from the following:
@@ -61,16 +54,16 @@ def _cleandoc(obj: Any) -> str:
 
 
 def _pydantic_recursion_protector(
-    cls: "Type[Model]",
+    cls: type[Model],
     *,
-    stack: Tuple,
-    exclude: Tuple[str, ...] = (),
-    include: Tuple[str, ...] = (),
-    computed: Tuple[str, ...] = (),
+    stack: tuple,
+    exclude: tuple[str, ...] = (),
+    include: tuple[str, ...] = (),
+    computed: tuple[str, ...] = (),
     name=None,
     allow_cycles: bool = False,
-    sort_alphabetically: Optional[bool] = None,
-) -> Optional[Type[PydanticModel]]:
+    sort_alphabetically: bool | None = None,
+) -> type[PydanticModel] | None:
     """
     It is an inner function to protect pydantic model creator against cyclic recursion
     """
@@ -108,13 +101,13 @@ def _pydantic_recursion_protector(
 
 
 class FieldMap(MutableMapping[str, Union[Field, ComputedFieldDescription]]):
-    def __init__(self, meta: PydanticMetaData, pk_field: Optional[Field] = None):
-        self._field_map: Dict[str, Union[Field, ComputedFieldDescription]] = {}
+    def __init__(self, meta: PydanticMetaData, pk_field: Field | None = None):
+        self._field_map: dict[str, Field | ComputedFieldDescription] = {}
         self.pk_raw_field = pk_field.model_field_name if pk_field is not None else ""
         if pk_field:
             self.pk_raw_field = pk_field.model_field_name
             self.field_map_update([pk_field], meta)
-        self.computed_fields: Dict[str, ComputedFieldDescription] = {}
+        self.computed_fields: dict[str, ComputedFieldDescription] = {}
 
     def __delitem__(self, __key):
         self._field_map.__delitem__(__key)
@@ -134,14 +127,14 @@ class FieldMap(MutableMapping[str, Union[Field, ComputedFieldDescription]]):
     def sort_alphabetically(self) -> None:
         self._field_map = {k: self._field_map[k] for k in sorted(self._field_map)}
 
-    def sort_definition_order(self, cls: "Type[Model]", computed: Tuple[str, ...]) -> None:
+    def sort_definition_order(self, cls: type[Model], computed: tuple[str, ...]) -> None:
         self._field_map = {
             k: self._field_map[k]
             for k in tuple(cls._meta.fields_map.keys()) + computed
             if k in self._field_map
         }
 
-    def field_map_update(self, fields: List[Field], meta: PydanticMetaData) -> None:
+    def field_map_update(self, fields: list[Field], meta: PydanticMetaData) -> None:
         for field in fields:
             name = field.model_field_name
             # Include or exclude field
@@ -158,7 +151,7 @@ class FieldMap(MutableMapping[str, Union[Field, ComputedFieldDescription]]):
                     self.pop(raw_field, None)
             self[name] = field
 
-    def computed_field_map_update(self, computed: Tuple[str, ...], cls: "Type[Model]"):
+    def computed_field_map_update(self, computed: tuple[str, ...], cls: type[Model]):
         self._field_map.update(
             {
                 k: ComputedFieldDescription(
@@ -172,15 +165,15 @@ class FieldMap(MutableMapping[str, Union[Field, ComputedFieldDescription]]):
 
 
 def pydantic_queryset_creator(
-    cls: "Type[Model]",
+    cls: type[Model],
     *,
     name=None,
-    exclude: Tuple[str, ...] = (),
-    include: Tuple[str, ...] = (),
-    computed: Tuple[str, ...] = (),
-    allow_cycles: Optional[bool] = None,
-    sort_alphabetically: Optional[bool] = None,
-) -> Type[PydanticListModel]:
+    exclude: tuple[str, ...] = (),
+    include: tuple[str, ...] = (),
+    computed: tuple[str, ...] = (),
+    allow_cycles: bool | None = None,
+    sort_alphabetically: bool | None = None,
+) -> type[PydanticListModel]:
     """
     Function to build a `Pydantic Model <https://docs.pydantic.dev/latest/concepts/models/>`__ list off Tortoise Model.
 
@@ -220,7 +213,7 @@ def pydantic_queryset_creator(
     model = create_model(
         lname,
         __base__=PydanticListModel,
-        root=(List[submodel], PydanticField(default_factory=list)),  # type: ignore
+        root=(list[submodel], PydanticField(default_factory=list)),  # type: ignore
     )
     # Copy the Model docstring over
     model.__doc__ = _cleandoc(cls)
@@ -233,25 +226,25 @@ def pydantic_queryset_creator(
 class PydanticModelCreator:
     def __init__(
         self,
-        cls: "Type[Model]",
-        name: Optional[str] = None,
-        exclude: Optional[Tuple[str, ...]] = None,
-        include: Optional[Tuple[str, ...]] = None,
-        computed: Optional[Tuple[str, ...]] = None,
-        optional: Optional[Tuple[str, ...]] = None,
-        allow_cycles: Optional[bool] = None,
-        sort_alphabetically: Optional[bool] = None,
+        cls: type[Model],
+        name: str | None = None,
+        exclude: tuple[str, ...] | None = None,
+        include: tuple[str, ...] | None = None,
+        computed: tuple[str, ...] | None = None,
+        optional: tuple[str, ...] | None = None,
+        allow_cycles: bool | None = None,
+        sort_alphabetically: bool | None = None,
         exclude_readonly: bool = False,
-        meta_override: Optional[Type] = None,
-        model_config: Optional[ConfigDict] = None,
-        validators: Optional[Dict[str, Any]] = None,
+        meta_override: type | None = None,
+        model_config: ConfigDict | None = None,
+        validators: dict[str, Any] | None = None,
         module: str = __name__,
         _stack: tuple = (),
         _as_submodel: bool = False,
     ) -> None:
-        self._cls: "Type[Model]" = cls
-        self._stack: Tuple[Tuple["Type[Model]", str, int], ...] = (
-            _stack  # ((Type[Model], field_name, max_recursion),)
+        self._cls: type[Model] = cls
+        self._stack: tuple[tuple[type[Model], str, int], ...] = (
+            _stack  # ((type[Model], field_name, max_recursion),)
         )
         self._is_default: bool = (
             exclude is None
@@ -301,8 +294,8 @@ class PydanticModelCreator:
 
         self._pconfig: ConfigDict
 
-        self._properties: Dict[str, Any] = dict()
-        self._relational_fields_index: List[Tuple[str, str]] = list()
+        self._properties: dict[str, Any] = dict()
+        self._relational_fields_index: list[tuple[str, str]] = list()
 
         self._model_description: ModelDescription = ModelDescription.from_model(cls)
 
@@ -328,7 +321,7 @@ class PydanticModelCreator:
             )
         return self.__hash
 
-    def get_name(self) -> Tuple[str, str]:
+    def get_name(self) -> tuple[str, str]:
         # If arguments are specified (different from the defaults), we append a hash to the
         # class name, to make it unique
         # We don't check by stack, as cycles get explicitly renamed.
@@ -377,7 +370,7 @@ class PydanticModelCreator:
         else:
             self._field_map.sort_definition_order(self._cls, self.meta.computed)
 
-    def create_pydantic_model(self) -> Type[PydanticModel]:
+    def create_pydantic_model(self) -> type[PydanticModel]:
         for field_name, field in self._field_map.items():
             self._process_field(field_name, field)
 
@@ -410,13 +403,13 @@ class PydanticModelCreator:
     def _process_field(
         self,
         field_name: str,
-        field: Union[Field, ComputedFieldDescription],
+        field: Field | ComputedFieldDescription,
     ) -> None:
-        json_schema_extra: Dict[str, Any] = {}
-        fconfig: Dict[str, Any] = {
+        json_schema_extra: dict[str, Any] = {}
+        fconfig: dict[str, Any] = {
             "json_schema_extra": json_schema_extra,
         }
-        field_property: Optional[Any] = None
+        field_property: Any | None = None
         is_to_one_relation: bool = False
         if isinstance(field, Field):
             field_property, is_to_one_relation = self._process_normal_field(
@@ -455,9 +448,9 @@ class PydanticModelCreator:
         self,
         field_name: str,
         field: Field,
-        json_schema_extra: Dict[str, Any],
-        fconfig: Dict[str, Any],
-    ) -> Tuple[Optional[Any], bool]:
+        json_schema_extra: dict[str, Any],
+        fconfig: dict[str, Any],
+    ) -> tuple[Any | None, bool]:
         if isinstance(
             field, (ForeignKeyFieldInstance, OneToOneFieldInstance, BackwardOneToOneRelation)
         ):
@@ -471,11 +464,11 @@ class PydanticModelCreator:
     def _process_single_field_relation(
         self,
         field_name: str,
-        field: Union[ForeignKeyFieldInstance, OneToOneFieldInstance, BackwardOneToOneRelation],
-        json_schema_extra: Dict[str, Any],
-    ) -> Optional[Type[PydanticModel]]:
+        field: ForeignKeyFieldInstance | OneToOneFieldInstance | BackwardOneToOneRelation,
+        json_schema_extra: dict[str, Any],
+    ) -> type[PydanticModel] | None:
         python_type = getattr(field, "related_model", field.field_type)
-        model: Optional[Type[PydanticModel]] = self._get_submodel(python_type, field_name)
+        model: type[PydanticModel] | None = self._get_submodel(python_type, field_name)
         if model:
             self._relational_fields_index.append((field_name, model.__name__))
             if field.null:
@@ -489,29 +482,29 @@ class PydanticModelCreator:
     def _process_many_field_relation(
         self,
         field_name: str,
-        field: Union[BackwardFKRelation, ManyToManyFieldInstance],
-    ) -> Optional[Type[List[Type[PydanticModel]]]]:
+        field: BackwardFKRelation | ManyToManyFieldInstance,
+    ) -> type[list[type[PydanticModel]]] | None:
         python_type = field.related_model
         model = self._get_submodel(python_type, field_name)
         if model:
             self._relational_fields_index.append((field_name, model.__name__))
-            return List[model]  # type: ignore
+            return list[model]  # type: ignore
         return None
 
     def _process_data_field(
         self,
         field_name: str,
         field: Field,
-        json_schema_extra: Dict[str, Any],
-        fconfig: Dict[str, Any],
-    ) -> Optional[Any]:
+        json_schema_extra: dict[str, Any],
+        fconfig: dict[str, Any],
+    ) -> Any | None:
         annotation = self._annotations.get(field_name, None)
         constraints = copy(field.constraints)
         if "readOnly" in constraints:
             json_schema_extra["readOnly"] = constraints["readOnly"]
             del constraints["readOnly"]
         fconfig.update(constraints)
-        python_type: Union[Type[Enum], Type[IntEnum], Type]
+        python_type: type[Enum] | type[IntEnum] | type
         if isinstance(field, (IntEnumFieldInstance, CharEnumFieldInstance)):
             python_type = field.enum_type
         else:
@@ -530,7 +523,7 @@ class PydanticModelCreator:
     def _process_computed_field(
         self,
         field: ComputedFieldDescription,
-    ) -> Optional[Any]:
+    ) -> Any | None:
         func = field.function
         annotation = get_annotations(self._cls, func).get("return", None)
         comment = _cleandoc(func)
@@ -541,8 +534,8 @@ class PydanticModelCreator:
         return None
 
     def _get_submodel(
-        self, _model: Optional["Type[Model]"], field_name: str
-    ) -> Optional[Type[PydanticModel]]:
+        self, _model: type[Model] | None, field_name: str
+    ) -> type[PydanticModel] | None:
         """Get Pydantic model for the submodel"""
 
         if _model:
@@ -551,7 +544,7 @@ class PydanticModelCreator:
             # Get pydantic schema for the submodel
             prefix_len = len(field_name) + 1
 
-            def get_fields_to_carry_on(field_tuple: Tuple[str, ...]) -> Tuple[str, ...]:
+            def get_fields_to_carry_on(field_tuple: tuple[str, ...]) -> tuple[str, ...]:
                 return tuple(
                     str(v[prefix_len:]) for v in field_tuple if v.startswith(field_name + ".")
                 )
@@ -576,21 +569,21 @@ class PydanticModelCreator:
 
 
 def pydantic_model_creator(
-    cls: "Type[Model]",
+    cls: type[Model],
     *,
     name=None,
-    exclude: Optional[Tuple[str, ...]] = None,
-    include: Optional[Tuple[str, ...]] = None,
-    computed: Optional[Tuple[str, ...]] = None,
-    optional: Optional[Tuple[str, ...]] = None,
-    allow_cycles: Optional[bool] = None,
-    sort_alphabetically: Optional[bool] = None,
+    exclude: tuple[str, ...] | None = None,
+    include: tuple[str, ...] | None = None,
+    computed: tuple[str, ...] | None = None,
+    optional: tuple[str, ...] | None = None,
+    allow_cycles: bool | None = None,
+    sort_alphabetically: bool | None = None,
     exclude_readonly: bool = False,
-    meta_override: Optional[Type] = None,
-    model_config: Optional[ConfigDict] = None,
-    validators: Optional[Dict[str, Any]] = None,
+    meta_override: type | None = None,
+    model_config: ConfigDict | None = None,
+    validators: dict[str, Any] | None = None,
     module: str = __name__,
-) -> Type[PydanticModel]:
+) -> type[PydanticModel]:
     """
     Function to build `Pydantic Model <https://docs.pydantic.dev/latest/concepts/models/>`__ off Tortoise Model.
 
